@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -39,11 +39,8 @@ import org.cactoos.proc.UncheckedBiProc;
  * @param <X> Type of input
  * @param <Y> Type of input
  * @since 0.20
- * @todo #1445:30min Introduce BiProcOf on the model of ProcOf, FuncOf, etc
- *  with constructors taking Func, BiFunc, Proc and BiProc as primary.
- *  Add tests similar to those of ProcOfTest, FuncOfTest, etc to fully cover
- *  the implementation. Use it where needed, for example in AndWithIndexTest.
  */
+@FunctionalInterface
 public interface BiProc<X, Y> {
 
     /**
