@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -39,12 +39,7 @@ import org.cactoos.Scalar;
  * @param <Z> Type of output
  * @since 0.20
  */
-public final class BiFuncOf<X, Y, Z> implements BiFunc<X, Y, Z> {
-
-    /**
-     * The func.
-     */
-    private final BiFunc<X, Y, Z> func;
+public final class BiFuncOf<X, Y, Z> extends BiFuncEnveloppe<X, Y, Z> {
 
     /**
      * Ctor.
@@ -92,14 +87,11 @@ public final class BiFuncOf<X, Y, Z> implements BiFunc<X, Y, Z> {
 
     /**
      * Ctor.
-     * @param fnc Func
+     * @param fnc The func
      */
     public BiFuncOf(final BiFunc<X, Y, Z> fnc) {
-        this.func = fnc;
-    }
-
-    @Override
-    public Z apply(final X first, final Y second) throws Exception {
-        return this.func.apply(first, second);
+        super(
+            fnc::apply
+        );
     }
 }
