@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -41,14 +41,14 @@ public final class FuncOf<X, Y> implements Func<X, Y> {
     /**
      * The func.
      */
-    private final Func<X, Y> func;
+    private final Func<? super X, ? extends Y> func;
 
     /**
      * Ctor.
      * @param proc The proc
      * @param result Result to return
      */
-    public FuncOf(final Proc<X> proc, final Y result) {
+    public FuncOf(final Proc<? super X> proc, final Y result) {
         this(
             input -> {
                 proc.exec(input);
@@ -61,7 +61,7 @@ public final class FuncOf<X, Y> implements Func<X, Y> {
      * Ctor.
      * @param scalar Origin scalar
      */
-    public FuncOf(final Scalar<Y> scalar) {
+    public FuncOf(final Scalar<? extends Y> scalar) {
         this(input -> scalar.value());
     }
 
@@ -69,7 +69,7 @@ public final class FuncOf<X, Y> implements Func<X, Y> {
      * Ctor.
      * @param fnc Func
      */
-    public FuncOf(final Func<X, Y> fnc) {
+    public FuncOf(final Func<? super X, ? extends Y> fnc) {
         this.func = fnc;
     }
 
