@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -95,12 +95,12 @@ public final class FuncWithFallback<X, Y> implements Func<X, Y> {
     /**
      * The func.
      */
-    private final Func<X, Y> func;
+    private final Func<? super X, ? extends Y> func;
 
     /**
      * The fallbacks.
      */
-    private final Iterable<Fallback<Y>> fallbacks;
+    private final Iterable<? extends Fallback<? extends Y>> fallbacks;
 
     /**
      * Ctor.
@@ -108,7 +108,8 @@ public final class FuncWithFallback<X, Y> implements Func<X, Y> {
      * @param fbks The fallbacks
      */
     @SafeVarargs
-    public FuncWithFallback(final Func<X, Y> fnc, final Fallback<Y>... fbks) {
+    public FuncWithFallback(final Func<? super X, ? extends Y> fnc,
+        final Fallback<? extends Y>... fbks) {
         this(fnc, new IterableOf<>(fbks));
     }
 
@@ -117,9 +118,8 @@ public final class FuncWithFallback<X, Y> implements Func<X, Y> {
      * @param fnc The func
      * @param fbks The fallbacks
      */
-    public FuncWithFallback(
-        final Func<X, Y> fnc, final Iterable<Fallback<Y>> fbks
-    ) {
+    public FuncWithFallback(final Func<? super X, ? extends Y> fnc,
+        final Iterable<? extends Fallback<? extends Y>> fbks) {
         this.func = fnc;
         this.fallbacks = fbks;
     }
