@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -159,7 +159,7 @@ public final class ResourceOf implements Input {
                 throw new IOException(
                     new FormattedText(
                         "The resource \"%s\" was not found in %s",
-                        input.asString(),
+                        input,
                         ldr
                     ).asString()
                 );
@@ -174,7 +174,7 @@ public final class ResourceOf implements Input {
      * @param fbk Fallback
      */
     public ResourceOf(final Text res, final Text fbk) {
-        this(res, input -> new InputOf(new BytesOf(fbk.asString())));
+        this(res, input -> new InputOf(fbk));
     }
 
     /**
