@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -23,6 +23,7 @@
  */
 package org.cactoos.iterable;
 
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 import java.util.Iterator;
 import org.cactoos.Fallback;
 import org.cactoos.Scalar;
@@ -31,9 +32,8 @@ import org.cactoos.scalar.And;
 import org.cactoos.scalar.Folded;
 import org.cactoos.scalar.Or;
 import org.cactoos.scalar.ScalarWithFallback;
-import org.cactoos.scalar.SumOfInt;
 import org.cactoos.scalar.Unchecked;
-import org.cactoos.text.TextOf;
+import org.cactoos.text.Joined;
 import org.cactoos.text.UncheckedText;
 
 /**
@@ -43,14 +43,13 @@ import org.cactoos.text.UncheckedText;
  *
  * @param <X> Type of item
  * @since 0.12
- * @checkstyle ClassDataAbstractionCouplingCheck (550 lines)
  */
 public final class IterableOf<X> implements Iterable<X> {
 
     /**
      * The encapsulated iterator.
      */
-    private final Scalar<Iterator<? extends X>> itr;
+    private final Scalar<? extends Iterator<? extends X>> itr;
 
     /**
      * Ctor.
@@ -74,7 +73,7 @@ public final class IterableOf<X> implements Iterable<X> {
      * Ctor.
      * @param sclr The encapsulated iterator of x
      */
-    public IterableOf(final Scalar<Iterator<? extends X>> sclr) {
+    public IterableOf(final Scalar<? extends Iterator<? extends X>> sclr) {
         this.itr = sclr;
     }
 
@@ -85,7 +84,7 @@ public final class IterableOf<X> implements Iterable<X> {
     }
 
     @Override
-    @edu.umd.cs.findbugs.annotations.SuppressFBWarnings("EQ_UNUSUAL")
+    @SuppressFBWarnings("EQ_UNUSUAL")
     @SuppressWarnings (value = "unchecked")
     public boolean equals(final Object other) {
         return new Unchecked<>(
@@ -96,7 +95,7 @@ public final class IterableOf<X> implements Iterable<X> {
                     () -> Iterable.class.isAssignableFrom(other.getClass()),
                     () -> {
                         final Iterable<X> compared = (Iterable<X>) other;
-                        return new ScalarWithFallback<Boolean>(
+                        return new ScalarWithFallback<>(
                             new And(
                                 (X value) -> true,
                                 new Matched<>(
@@ -117,16 +116,12 @@ public final class IterableOf<X> implements Iterable<X> {
         ).value();
     }
 
-    // @checkstyle MagicNumberCheck (30 lines)
     @Override
     public int hashCode() {
         return new Unchecked<>(
             new Folded<>(
                 42,
-                (hash, entry) -> new SumOfInt(
-                    () -> 37 * hash,
-                    entry::hashCode
-                ).value(),
+                (hash, entry) -> 37 * hash + entry.hashCode(),
                 this
             )
         ).value();
@@ -134,6 +129,14 @@ public final class IterableOf<X> implements Iterable<X> {
 
     @Override
     public String toString() {
-        return new UncheckedText(new TextOf(this)).asString();
+        return new UncheckedText(
+            new Joined(
+                ", ",
+                new Mapped<>(
+                    Object::toString,
+                    this
+                )
+            )
+        ).asString();
     }
 }
