@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -62,7 +62,7 @@ public final class Matched<X> extends IterableEnvelope<X> {
     ) {
         super(
             new IterableOf<>(
-                new org.cactoos.iterator.Matched<>(
+                () -> new org.cactoos.iterator.Matched<>(
                     fnc, fst.iterator(), snd.iterator()
                 )
             )
