@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -51,7 +51,7 @@ public final class Sticky<X> extends IterableEnvelope<X> {
      */
     public Sticky(final Iterable<? extends X> iterable) {
         super(
-            new IterableOf<X>(
+            new IterableOf<>(
                 new Mapped<>(
                     Iterable::iterator,
                     new org.cactoos.scalar.Sticky<>(
