@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -31,15 +31,9 @@ import org.cactoos.iterable.Joined;
 import org.cactoos.iterable.Mapped;
 
 /**
- * Iterable as {@link Map}.
+ * Implementation of {@link Map}.
  *
- * <p>
- * This class should be used very carefully. You must understand that it will
- * fetch the entire content of the encapsulated {@link Map} on each method call.
- * It doesn't cache the data anyhow.
- *
- * <p>
- * There is no thread-safety guarantee.
+ * <p>There is no thread-safety guarantee.
  *
  * @param <X> Type of key
  * @param <Y> Type of value
@@ -47,6 +41,15 @@ import org.cactoos.iterable.Mapped;
  */
 public final class MapOf<X, Y> extends MapEnvelope<X, Y> {
 
+    /**
+     * Ctor.
+     * @param key The key
+     * @param value The value
+     */
+    public MapOf(final X key, final Y value) {
+        this(new MapEntry<>(key, value));
+    }
+
     /**
      * Ctor.
      * @param list List of entries
@@ -56,6 +59,20 @@ public final class MapOf<X, Y> extends MapEnvelope<X, Y> {
         this(new IterableOf<>(list));
     }
 
+    /**
+     * Ctor.
+     * @param src Map to extend
+     * @param key New key
+     * @param value New value
+     */
+    public MapOf(
+        final Map<? extends X, ? extends Y> src,
+        final X key,
+        final Y value
+    ) {
+        this(src, new MapEntry<>(key, value));
+    }
+
     /**
      * Ctor.
      * @param src The map to extend
@@ -156,9 +173,22 @@ public final class MapOf<X, Y> extends MapEnvelope<X, Y> {
      * @param entries List of the entries
      */
     public MapOf(final Iterable<Map.Entry<? extends X, ? extends Y>> entries) {
-        super(new HashMap<>());
-        for (final Entry<? extends X, ? extends Y> entry : entries) {
-            this.put(entry.getKey(), entry.getValue());
+        super(MapOf.make(entries));
+    }
+
+    /**
+     * Ctor.
+     * @param entries List of the entries
+     * @param <X> Key type
+     * @param <Y> Value type
+     * @return Map created
+     */
+    private static <X, Y> Map<X, Y> make(
+        final Iterable<Map.Entry<? extends X, ? extends Y>> entries) {
+        final Map<X, Y> map = new HashMap<>(0);
+        for (final Map.Entry<? extends X, ? extends Y> entry : entries) {
+            map.put(entry.getKey(), entry.getValue());
         }
+        return map;
     }
 }
