@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -28,8 +28,8 @@ import org.cactoos.func.FuncOf;
 import org.cactoos.scalar.And;
 
 /**
- * Executes a {@link org.cactoos.Proc} for each element of an
- * {@link java.lang.Iterable}
+ * Executes a {@link Proc} for each element of an
+ * {@link Iterable}
  *
  * <p>
  * This class can be effectively used to iterate through a collection, just like
@@ -49,24 +49,24 @@ import org.cactoos.scalar.And;
  * @param <X> The type to iterate over
  * @since 1.0
  */
-public final class ForEach<X> implements Proc<Iterable<X>> {
+public final class ForEach<X> implements Proc<Iterable<? extends X>> {
 
     /**
      * The proc.
      */
-    private final Proc<X> proc;
+    private final Proc<? super X> proc;
 
     /**
      * Ctor.
      *
      * @param proc The proc to execute
      */
-    public ForEach(final Proc<X> proc) {
+    public ForEach(final Proc<? super X> proc) {
         this.proc = proc;
     }
 
     @Override
-    public void exec(final Iterable<X> input) throws Exception {
+    public void exec(final Iterable<? extends X> input) throws Exception {
         new And(
             new FuncOf<>(this.proc, true), input
         ).value();
