@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -34,18 +34,13 @@ import org.cactoos.Proc;
  * @param <X> Type of input
  * @since 0.12
  */
-public final class ProcOf<X> implements Proc<X> {
-
-    /**
-     * The proc.
-     */
-    private final Proc<X> proc;
+public final class ProcOf<X> extends ProcEnvelope<X> {
 
     /**
      * Ctor.
      * @param fnc The proc
      */
-    public ProcOf(final Func<X, ?> fnc) {
+    public ProcOf(final Func<? super X, ?> fnc) {
         this(
             input -> {
                 fnc.apply(input);
@@ -57,12 +52,7 @@ public final class ProcOf<X> implements Proc<X> {
      * Ctor.
      * @param prc The proc
      */
-    public ProcOf(final Proc<X> prc) {
-        this.proc = prc;
-    }
-
-    @Override
-    public void exec(final X input) throws Exception {
-        this.proc.exec(input);
+    public ProcOf(final Proc<? super X> prc) {
+        super(prc);
     }
 }
