@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -42,24 +42,14 @@ import org.cactoos.Scalar;
  * @param <T> Type of output
  * @since 0.12
  */
-public final class CallableOf<T> implements Callable<T> {
-
-    /**
-     * Original callable.
-     */
-    private final Scalar<T> scalar;
+public final class CallableOf<T> extends CallableEnvelope<T> {
 
     /**
      * Ctor.
      * @param slr Encapsulated scalar
      * @since 0.41
      */
-    public CallableOf(final Scalar<T> slr) {
-        this.scalar = slr;
-    }
-
-    @Override
-    public T call() throws Exception {
-        return this.scalar.value();
+    public CallableOf(final Scalar<? extends T> slr) {
+        super(slr::value);
     }
 }
