@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -28,6 +28,7 @@ import java.util.Iterator;
 import org.cactoos.Func;
 import org.cactoos.Scalar;
 import org.cactoos.func.FuncOf;
+import org.cactoos.iterable.IterableOf;
 import org.cactoos.text.FormattedText;
 
 /**
@@ -53,7 +54,7 @@ public final class ItemAt<T> implements Scalar<T> {
      * @param position Position
      * @param iterable Iterable
      */
-    public ItemAt(final int position, final Iterable<T> iterable) {
+    public ItemAt(final int position, final Iterable<? extends T> iterable) {
         this(
             position,
             itr -> {
@@ -78,7 +79,7 @@ public final class ItemAt<T> implements Scalar<T> {
     public ItemAt(
         final int position,
         final T fallback,
-        final Iterable<T> iterable
+        final Iterable<? extends T> iterable
     ) {
         this(position, new FuncOf<>(new Constant<>(fallback)), iterable);
     }
@@ -92,12 +93,11 @@ public final class ItemAt<T> implements Scalar<T> {
      */
     public ItemAt(
         final int position,
-        final Func<Iterable<T>, T> fallback,
-        final Iterable<T> iterable
+        final Func<? super Iterable<? extends T>, ? extends T> fallback,
+        final Iterable<? extends T> iterable
     ) {
-        this.saved = new Sticky<T>(
+        this.saved = new Sticky<>(
             () -> {
-                final T ret;
                 if (position < 0) {
                     throw new IOException(
                         new FormattedText(
@@ -106,15 +106,16 @@ public final class ItemAt<T> implements Scalar<T> {
                         ).asString()
                     );
                 }
-                final Iterator<T> src = iterable.iterator();
+                final Iterator<? extends T> src = iterable.iterator();
                 int cur;
                 for (cur = 0; cur < position && src.hasNext(); ++cur) {
                     src.next();
                 }
+                final T ret;
                 if (cur == position && src.hasNext()) {
                     ret = src.next();
                 } else {
-                    ret = fallback.apply(() -> src);
+                    ret = fallback.apply(new IterableOf<>(src));
                 }
                 return ret;
             }
