@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -43,7 +43,6 @@ import org.cactoos.text.TextOf;
  * <p>There is no thread-safety guarantee.
  *
  * @since 0.12
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  */
 public final class PropertiesOf implements Scalar<Properties> {
 
@@ -97,7 +96,7 @@ public final class PropertiesOf implements Scalar<Properties> {
      * @param entries The map with properties
      * @since 0.23
      */
-    public PropertiesOf(final Iterable<Map.Entry<?, ?>> entries) {
+    public PropertiesOf(final Iterable<? extends Map.Entry<?, ?>> entries) {
         this(
             new MapOf<>(
                 input -> new MapEntry<>(
@@ -131,7 +130,7 @@ public final class PropertiesOf implements Scalar<Properties> {
      * Ctor.
      * @param sclr The underlying properties
      */
-    private PropertiesOf(final Scalar<Properties> sclr) {
+    private PropertiesOf(final Scalar<? extends Properties> sclr) {
         this.scalar = new IoChecked<>(sclr);
     }
 
