@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -24,6 +24,7 @@
 package org.cactoos.scalar;
 
 import java.util.Comparator;
+import java.util.Iterator;
 import java.util.Map;
 import org.cactoos.Fallback;
 import org.cactoos.Scalar;
@@ -47,12 +48,12 @@ public final class ScalarWithFallback<T> implements Scalar<T> {
     /**
      * The origin scalar.
      */
-    private final Scalar<T> origin;
+    private final Scalar<? extends T> origin;
 
     /**
      * The fallback.
      */
-    private final Iterable<Fallback<T>> fallbacks;
+    private final Iterable<? extends Fallback<? extends T>> fallbacks;
 
     /**
      * Ctor.
@@ -61,8 +62,8 @@ public final class ScalarWithFallback<T> implements Scalar<T> {
      */
     @SafeVarargs
     public ScalarWithFallback(
-        final Scalar<T> origin,
-        final Fallback<T>... fbks
+        final Scalar<? extends T> origin,
+        final Fallback<? extends T>... fbks
     ) {
         this(origin, new IterableOf<>(fbks));
     }
@@ -72,8 +73,8 @@ public final class ScalarWithFallback<T> implements Scalar<T> {
      * @param origin Original scalar
      * @param fbks Fallbacks
      */
-    public ScalarWithFallback(final Scalar<T> origin,
-        final Iterable<Fallback<T>> fbks) {
+    public ScalarWithFallback(final Scalar<? extends T> origin,
+        final Iterable<? extends Fallback<? extends T>> fbks) {
         this.origin = origin;
         this.fallbacks = fbks;
     }
@@ -103,17 +104,19 @@ public final class ScalarWithFallback<T> implements Scalar<T> {
      */
     @SuppressWarnings("PMD.AvoidThrowingRawExceptionTypes")
     private T fallback(final Throwable exp) throws Exception {
-        final Sorted<Map.Entry<Fallback<T>, Integer>> candidates =
+        final Iterator<? extends Map.Entry<Fallback<? extends T>, Integer>> candidates =
             new Sorted<>(
                 Comparator.comparing(Map.Entry::getValue),
                 new Filtered<>(
-                    entry -> new Not(
-                        new Equals<>(
-                            entry::getValue,
-                            () -> Integer.MIN_VALUE
+                    new org.cactoos.func.Flattened<>(
+                        entry -> new Not(
+                            new Equals<Integer, Integer>(
+                                entry::getValue,
+                                new Constant<>(Integer.MIN_VALUE)
+                            )
                         )
-                    ).value(),
-                    new MapOf<>(
+                    ),
+                    new MapOf<Fallback<? extends T>, Integer>(
                         fbk -> fbk,
                         fbk -> fbk.support(exp),
                         this.fallbacks
