@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -34,7 +34,6 @@ import org.cactoos.scalar.Ternary;
  * <p>There is no thread-safety guarantee.
  *
  * @since 0.29
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  */
 public final class Abbreviated extends TextEnvelope {
 
@@ -53,9 +52,9 @@ public final class Abbreviated extends TextEnvelope {
      *
      * <p> By default, the max line width is 80 characters.
      *
-     * @param text The Text
+     * @param text The CharSequence
      */
-    public Abbreviated(final String text) {
+    public Abbreviated(final CharSequence text) {
         this(new TextOf(text));
     }
 
@@ -73,10 +72,10 @@ public final class Abbreviated extends TextEnvelope {
     /**
      * Ctor.
      *
-     * @param text A String
+     * @param text A CharSequence
      * @param max Max width of the result string
      */
-    public Abbreviated(final String text, final int max) {
+    public Abbreviated(final CharSequence text, final int max) {
         this(new TextOf(text), max);
     }
 
@@ -90,7 +89,7 @@ public final class Abbreviated extends TextEnvelope {
             new Flattened(
                 new Ternary<>(
                     new ScalarOf<>(() -> new Sticky(text)),
-                    (Text t) -> new LengthOf(t).longValue() <= max,
+                    (Text t) -> new LengthOf(t).value() <= max,
                     t -> t,
                     t -> new FormattedText(
                         "%s%s",
