@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -37,9 +37,9 @@ public final class Base64Decoded extends TextEnvelope {
     /**
      * Ctor.
      *
-     * @param input The String
+     * @param input The CharSequence
      */
-    public Base64Decoded(final String input) {
+    public Base64Decoded(final CharSequence input) {
         this(new TextOf(input));
     }
 
