@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -34,7 +34,7 @@ import org.cactoos.iterable.Mapped;
  *
  * @since 0.47
  */
-public class Concatenated extends TextEnvelope {
+public final class Concatenated extends TextEnvelope {
 
     /**
      * Ctor.
@@ -46,9 +46,9 @@ public class Concatenated extends TextEnvelope {
 
     /**
      * Ctor.
-     * @param strs Strings to be concatenated
+     * @param strs CharSequences to be concatenated
      */
-    public Concatenated(final String... strs) {
+    public Concatenated(final CharSequence... strs) {
         this(
             new Mapped<>(
                 TextOf::new,
