@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -94,7 +94,7 @@ public final class FormattedText extends TextEnvelope {
      * @param ptn Pattern
      * @param arguments Arguments
      */
-    public FormattedText(final String ptn, final Collection<Object> arguments) {
+    public FormattedText(final CharSequence ptn, final Collection<?> arguments) {
         this(ptn, Locale.getDefault(Locale.Category.FORMAT), arguments);
     }
 
@@ -116,9 +116,9 @@ public final class FormattedText extends TextEnvelope {
      * @param arguments Arguments
      */
     public FormattedText(
-        final String ptn,
+        final CharSequence ptn,
         final Locale locale,
-        final Collection<Object> arguments
+        final Collection<?> arguments
     ) {
         this(new TextOf(ptn), locale, arguments);
     }
@@ -133,7 +133,7 @@ public final class FormattedText extends TextEnvelope {
     public FormattedText(
         final Text ptn,
         final Locale locale,
-        final Collection<Object> args
+        final Collection<?> args
     ) {
         super(
             new Mapped(
