@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -39,7 +39,7 @@ public final class Lowered extends TextEnvelope {
      * Ctor.
      * @param text The text
      */
-    public Lowered(final String text) {
+    public Lowered(final CharSequence text) {
         this(new TextOf(text));
     }
 
