@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -46,8 +46,7 @@ public final class PaddedStart extends TextEnvelope {
             new Flattened(
                 () -> {
                     final String original = text.asString();
-                    return new Joined(
-                        new TextOf(""),
+                    return new Concatenated(
                         new Repeated(
                             new TextOf(symbol), length - original.length()
                         ),
