@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -24,8 +24,6 @@
 package org.cactoos.text;
 
 import org.cactoos.Text;
-import org.cactoos.func.FuncOf;
-import org.cactoos.scalar.Constant;
 import org.cactoos.scalar.ScalarOf;
 import org.cactoos.scalar.Ternary;
 
@@ -40,10 +38,10 @@ public final class PrefixOf extends TextEnvelope {
 
     /**
      * Ctor.
-     * @param text Text representing the text value
-     * @param boundary String to which text will be split
+     * @param text CharSequence representing the text value
+     * @param boundary CharSequence to which text will be split
      */
-    public PrefixOf(final String text, final String boundary) {
+    public PrefixOf(final CharSequence text, final CharSequence boundary) {
         this(new TextOf(text), boundary);
     }
 
@@ -52,13 +50,13 @@ public final class PrefixOf extends TextEnvelope {
      * @param text Text representing the text value
      * @param boundary String to which text will be split
      */
-    public PrefixOf(final Text text, final String boundary) {
+    public PrefixOf(final Text text, final CharSequence boundary) {
         super(
             new Flattened(
                 new Ternary<>(
                     new ScalarOf<>(() -> new Sticky(text)),
-                    (Text t) -> t.asString().indexOf(boundary) >= 0,
-                    t -> new Sub(t, 0, s -> s.indexOf(boundary)),
+                    (Text t) -> t.asString().contains(boundary.toString()),
+                    t -> new Sub(t, 0, s -> s.indexOf(boundary.toString())),
                     t -> t
                 )
             )
