@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -49,17 +49,17 @@ public final class Replaced extends TextEnvelope {
      */
     public Replaced(
         final Text text,
-        final String find,
-        final String replace
+        final CharSequence find,
+        final CharSequence replace
     ) {
-        this(text, () -> Pattern.compile(find), matcher -> replace);
+        this(text, () -> Pattern.compile(find.toString()), matcher -> replace);
     }
 
     /**
      * Ctor.
      * <p>
      * The given {@link Pattern regex} is used to produce a
-     * {@link Pattern#matcher(java.lang.CharSequence) matcher} that will be
+     * {@link Pattern#matcher(CharSequence) matcher} that will be
      * transformed by {@code func} into a replacement string to replace each
      * {@link Matcher#find() matching} substring.
      * <p>
@@ -82,7 +82,7 @@ public final class Replaced extends TextEnvelope {
     public Replaced(
         final Text text,
         final Scalar<Pattern> regex,
-        final Func<Matcher, String> func
+        final Func<? super Matcher, ? extends CharSequence> func
     ) {
         super(
             new Mapped(
@@ -92,7 +92,7 @@ public final class Replaced extends TextEnvelope {
                     while (matcher.find()) {
                         matcher.appendReplacement(
                             buffer,
-                            func.apply(matcher)
+                            func.apply(matcher).toString()
                         );
                     }
                     matcher.appendTail(buffer);
