@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -50,7 +50,7 @@ public final class Strict extends TextEnvelope {
      * @param predicate The Func as a predicate
      * @param origin The Text
      */
-    public Strict(final Func<String, Boolean> predicate, final Text origin) {
+    public Strict(final Func<? super String, Boolean> predicate, final Text origin) {
         super(
             new Mapped(
                 str -> {
