@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -42,7 +42,7 @@ public final class Sub extends TextEnvelope {
      * @param text The String
      * @param strt Start position in the text
      */
-    public Sub(final String text, final int strt) {
+    public Sub(final CharSequence text, final int strt) {
         this(new TextOf(text), strt);
     }
 
@@ -52,7 +52,7 @@ public final class Sub extends TextEnvelope {
      * @param strt Start position in the text
      * @param finish End position in the text
      */
-    public Sub(final String text, final int strt, final int finish) {
+    public Sub(final CharSequence text, final int strt, final int finish) {
         this(new TextOf(text), strt, finish);
     }
 
@@ -79,7 +79,7 @@ public final class Sub extends TextEnvelope {
      * @param text The Text
      * @param strt Start position in the text
      */
-    public Sub(final Text text, final Func<String, Integer> strt) {
+    public Sub(final Text text, final Func<? super String, Integer> strt) {
         this(text, strt, String::length);
     }
 
@@ -109,7 +109,8 @@ public final class Sub extends TextEnvelope {
      * @param strt Start position in the text
      * @param finish End position in the text
      */
-    public Sub(final Text text, final int strt, final Func<String, Integer> finish) {
+    public Sub(final Text text, final int strt,
+        final Func<? super String, Integer> finish) {
         this(text, new Constant<>(strt), finish);
     }
 
@@ -131,7 +132,7 @@ public final class Sub extends TextEnvelope {
      * @param finish End position in the text
      */
     public Sub(final Text text, final Scalar<Integer> strt,
-        final Func<String, Integer> finish) {
+        final Func<? super String, Integer> finish) {
         this(text, new FuncOf<>(strt), finish);
     }
 
@@ -141,8 +142,8 @@ public final class Sub extends TextEnvelope {
      * @param start Start position in the text
      * @param end End position in the text
      */
-    public Sub(final Text text, final Func<String, Integer> start,
-        final Func<String, Integer> end) {
+    public Sub(final Text text, final Func<? super String, Integer> start,
+        final Func<? super String, Integer> end) {
         super(
             new Mapped(
                 origin -> {
