@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -41,7 +41,7 @@ public final class SuffixOf extends TextEnvelope {
      * @param text Text representing the text value
      * @param boundary String after which text will be split
      */
-    public SuffixOf(final String text, final String boundary) {
+    public SuffixOf(final CharSequence text, final CharSequence boundary) {
         this(new TextOf(text), boundary);
     }
 
@@ -50,15 +50,16 @@ public final class SuffixOf extends TextEnvelope {
      * @param text Text representing the text value
      * @param boundary String after which text will be split
      */
-    public SuffixOf(final Text text, final String boundary) {
+    public SuffixOf(final Text text, final CharSequence boundary) {
         super(
             new Flattened(
                 new Ternary<>(
                     new ScalarOf<>(() -> new Sticky(text)),
-                    (Text t) -> t.asString().indexOf(boundary) >= 0,
+                    (Text t) -> t.asString().contains(boundary.toString()),
                     t -> new Sub(
                         t,
-                        s -> s.indexOf(boundary) + boundary.length()
+                        s -> s.indexOf(boundary.toString())
+                            + boundary.length()
                     ),
                     t -> new TextOf("")
                 )
