@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -40,6 +40,6 @@ public final class Trimmed extends TextEnvelope {
      * @param text The text
      */
     public Trimmed(final Text text) {
-        super(new Mapped(str -> str.trim(), text));
+        super(new Mapped(String::trim, text));
     }
 }
