@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -49,7 +49,7 @@ public final class TrimmedLeft extends TextEnvelope {
                             string.charAt(cursor)
                         )
                     ) {
-                        cursor = cursor + 1;
+                        cursor += 1;
                     }
                     return string.substring(cursor);
                 },
