@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -44,7 +44,7 @@ public final class TrimmedRight extends TextEnvelope {
                 string -> {
                     int cursor = string.length() - 1;
                     while (cursor >= 0 && Character.isWhitespace(string.charAt(cursor))) {
-                        cursor = cursor - 1;
+                        cursor -= 1;
                     }
                     return string.substring(0, cursor + 1);
                 },
