@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -28,16 +28,15 @@ import org.cactoos.iterable.Filtered;
 import org.cactoos.iterable.IterableOf;
 import org.cactoos.iterable.Mapped;
 import org.cactoos.scalar.LengthOf;
-import org.hamcrest.core.IsEqual;
 import org.junit.jupiter.api.Test;
 import org.llorllale.cactoos.matchers.Assertion;
+import org.llorllale.cactoos.matchers.HasValue;
 
 /**
  * Test case for {@link Chained}.
  *
  * @since 0.7
  * @checkstyle JavadocMethodCheck (500 lines)
- * @checkstyle MagicNumber (500 line)
  */
 final class ChainedTest {
 
@@ -56,8 +55,8 @@ final class ChainedTest {
                         new IterableOf<>("public", "final", "class")
                     )
                 )
-            ).intValue(),
-            new IsEqual<>(3)
+            ),
+            new HasValue<>(3L)
         ).affirm();
     }
 
@@ -80,8 +79,8 @@ final class ChainedTest {
                         new IterableOf<>("private", "static", "String")
                     )
                 )
-            ).intValue(),
-            new IsEqual<>(2)
+            ),
+            new HasValue<>(2L)
         ).affirm();
     }
 }
