@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -28,7 +28,7 @@ import org.cactoos.proc.ProcOf;
 import org.cactoos.scalar.Constant;
 import org.junit.jupiter.api.Test;
 import org.llorllale.cactoos.matchers.Assertion;
-import org.llorllale.cactoos.matchers.MatcherOf;
+import org.llorllale.cactoos.matchers.Satisfies;
 
 /**
  * Test case for {@link FuncOf}.
@@ -44,13 +44,11 @@ final class FuncOfTest {
             "Must convert Proc into Func",
             new FuncOf<>(
                 new ProcOf<>(
-                    input -> {
-                        done.set(input);
-                    }
+                    done::set
                 ),
                 result
             ),
-            new MatcherOf<>(
+            new Satisfies<>(
                 func -> {
                     final Object input = new Object();
                     final Object res = func.apply(input);
@@ -66,7 +64,7 @@ final class FuncOfTest {
         new Assertion<>(
             "Must convert Scalar into Func",
             new FuncOf<>(new Constant<>(result)),
-            new MatcherOf<>(
+            new Satisfies<>(
                 func -> {
                     final Object res = func.apply("discarded");
                     return res.equals(result);
@@ -80,7 +78,7 @@ final class FuncOfTest {
         new Assertion<>(
             "Must convert Lambda into Func",
             new FuncOf<>(input -> input),
-            new MatcherOf<>(
+            new Satisfies<>(
                 func -> {
                     final Object input = new Object();
                     final Object res = func.apply(input);
