@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -30,14 +30,13 @@ import org.cactoos.Fallback;
 import org.cactoos.iterable.IterableOf;
 import org.junit.Test;
 import org.llorllale.cactoos.matchers.Assertion;
-import org.llorllale.cactoos.matchers.FuncApplies;
+import org.llorllale.cactoos.matchers.IsApplicable;
 
 /**
  * Test case for {@link FuncWithFallback}.
  *
  * @since 0.2
  * @checkstyle JavadocMethodCheck (500 lines)
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  */
 @SuppressWarnings("unchecked")
 public final class FuncWithFallbackTest {
@@ -47,14 +46,14 @@ public final class FuncWithFallbackTest {
         final String expected = "It's success";
         new Assertion<>(
             "Can't use the main function if no exception",
-            new FuncWithFallback<Integer, String>(
+            new FuncWithFallback<>(
                 input -> expected,
                 new Fallback.From<>(
                     Exception.class,
                     ex -> "In case of failure..."
                 )
             ),
-            new FuncApplies<>(1, expected)
+            new IsApplicable<>(1, expected)
         ).affirm();
     }
 
@@ -63,13 +62,13 @@ public final class FuncWithFallbackTest {
         final String expected = "Never mind";
         new Assertion<>(
             "Can't use the callback in case of exception",
-            new FuncWithFallback<Integer, String>(
+            new FuncWithFallback<>(
                 input -> {
                     throw new IOException("Failure");
                 },
                 new Fallback.From<>(IOException.class, ex -> expected)
             ),
-            new FuncApplies<>(1, expected)
+            new IsApplicable<>(1, expected)
         ).affirm();
     }
 
@@ -78,7 +77,7 @@ public final class FuncWithFallbackTest {
         final String expected = "Fallback from InterruptedException";
         new Assertion<>(
             "Can't use a fallback from Interrupted in case of exception",
-            new FuncWithFallback<Integer, String>(
+            new FuncWithFallback<>(
                 input -> {
                     throw new InterruptedException(
                         "Failure with InterruptedException"
@@ -86,7 +85,7 @@ public final class FuncWithFallbackTest {
                 },
                 new Fallback.From<>(InterruptedException.class, exp -> expected)
             ),
-            new FuncApplies<>(1, expected)
+            new IsApplicable<>(1, expected)
         ).affirm();
     }
 
@@ -110,7 +109,7 @@ public final class FuncWithFallbackTest {
                     )
                 )
             ),
-            new FuncApplies<>(1, expected)
+            new IsApplicable<>(1, expected)
         ).affirm();
     }
 
