@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -32,28 +32,22 @@ import java.net.URL;
 import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.nio.file.Path;
-import java.security.SecureRandom;
-import java.security.cert.X509Certificate;
 import java.util.concurrent.atomic.AtomicBoolean;
-import javax.net.ssl.HttpsURLConnection;
-import javax.net.ssl.SSLContext;
-import javax.net.ssl.TrustManager;
-import javax.net.ssl.X509TrustManager;
 import org.cactoos.bytes.BytesOf;
-import org.cactoos.iterable.IterableOf;
 import org.cactoos.text.TextOf;
 import org.hamcrest.core.AllOf;
 import org.hamcrest.core.IsEqual;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 import org.llorllale.cactoos.matchers.Assertion;
 import org.llorllale.cactoos.matchers.EndsWith;
-import org.llorllale.cactoos.matchers.InputHasContent;
-import org.llorllale.cactoos.matchers.MatcherOf;
+import org.llorllale.cactoos.matchers.HasContent;
+import org.llorllale.cactoos.matchers.HasString;
+import org.llorllale.cactoos.matchers.IsText;
+import org.llorllale.cactoos.matchers.IsTrue;
 import org.llorllale.cactoos.matchers.MatchesRegex;
+import org.llorllale.cactoos.matchers.Satisfies;
 import org.llorllale.cactoos.matchers.StartsWith;
-import org.llorllale.cactoos.matchers.TextHasString;
 import org.takes.http.FtRemote;
 import org.takes.tk.TkHtml;
 
@@ -61,20 +55,12 @@ import org.takes.tk.TkHtml;
  * Test case for {@link InputOf}.
  *
  * @since 0.1
- * @checkstyle JavadocMethodCheck (500 lines)
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  * @checkstyle ClassFanOutComplexityCheck (500 lines)
  */
-@SuppressWarnings({ "PMD.TooManyMethods", "PMD.ExcessiveImports", "unchecked" })
-public final class InputOfTest {
-    /**
-     * Temporary files and folders generator.
-     */
-    @Rule
-    public final TemporaryFolder folder = new TemporaryFolder();
-
+@SuppressWarnings({"PMD.TooManyMethods", "PMD.ExcessiveImports", "unchecked"})
+final class InputOfTest {
     @Test
-    public void readsAlternativeInputForFileCase() {
+    void readsAlternativeInputForFileCase() {
         new Assertion<>(
             "must read alternative source from file not found",
             new TextOf(
@@ -90,52 +76,48 @@ public final class InputOfTest {
     }
 
     @Test
-    public void readsSimpleFileContent() throws IOException {
-        final Path temp = this.folder.newFile("cactoos-1.txt-1")
-            .toPath();
+    void readsSimpleFileContent(final @TempDir Path folder) throws IOException {
+        final Path temp = folder.resolve("cactoos-1.txt-1");
         final String content = "Hello, товарищ!";
         Files.write(temp, content.getBytes(StandardCharsets.UTF_8));
         new Assertion<>(
             "must read file content",
             new InputOf(temp),
-            new InputHasContent(content)
+            new HasContent(content)
         ).affirm();
     }
 
     @Test
-    public void closesInputStream() throws Exception {
+    void closesInputStream() throws Exception {
         final AtomicBoolean closed = new AtomicBoolean();
         final InputStream input = new ByteArrayInputStream(
             "how are you?".getBytes()
         );
-        new Assertion<>(
-            "must close InputStream correctly",
-            new TextOf(
-                new InputOf(
-                    new InputStream() {
-                        @Override
-                        public int read() throws IOException {
-                            return input.read();
-                        }
+        new TextOf(
+            new InputOf(
+                new InputStream() {
+                    @Override
+                    public int read() throws IOException {
+                        return input.read();
+                    }
 
-                        @Override
-                        public void close() throws IOException {
-                            input.close();
-                            closed.set(true);
-                        }
+                    @Override
+                    public void close() throws IOException {
+                        input.close();
+                        closed.set(true);
                     }
-                )
-            ).asString(),
-            new MatcherOf<>(
-                text -> {
-                    return closed.get();
                 }
             )
+        ).asString();
+        new Assertion<>(
+            "must close InputStream correctly",
+            closed.get(),
+            new IsTrue()
         ).affirm();
     }
 
     @Test
-    public void readsFileContent() throws Exception {
+    void readsFileContent() throws Exception {
         new Assertion<>(
             "must read bytes from a file-system URL",
             new BytesOf(
@@ -144,13 +126,13 @@ public final class InputOfTest {
                         "/org/cactoos/io/InputOf.class"
                     )
                 )
-            ).asBytes().length,
-            new MatcherOf<>(len -> len > 0)
+            ).asBytes(),
+            new Satisfies<>(arr -> arr.length > 0)
         ).affirm();
     }
 
     @Test
-    public void readsRealUrl() throws IOException {
+    void readsRealUrl() throws Exception {
         new FtRemote(new TkHtml("<html>How are you?</html>")).exec(
             home -> new Assertion<>(
                 "must fetch bytes from the URL",
@@ -163,25 +145,24 @@ public final class InputOfTest {
     }
 
     @Test
-    public void readsStringUrl() throws IOException {
+    void readsStringUrl() throws IOException {
         new Assertion<>(
             "must fetch bytes from the HTTPS URL",
             new TextOf(
                 new BytesOf(
                     new InputOf(
                         new URL(
-                            // @checkstyle LineLength (1 line)
                             "file:src/test/resources/org/cactoos/large-text.txt"
                         )
                     )
                 )
             ),
-            new TextHasString("Lorem ipsum")
+            new HasString("Lorem ipsum")
         ).affirm();
     }
 
     @Test
-    public void readsStringIntoBytes() throws Exception {
+    void readsStringIntoBytes() throws Exception {
         new Assertion<>(
             "must read bytes from Input",
             new TextOf(
@@ -191,16 +172,14 @@ public final class InputOfTest {
                 StandardCharsets.UTF_8
             ),
             new AllOf<>(
-                new IterableOf<>(
-                    new StartsWith("Hello, "),
-                    new EndsWith("друг!")
-                )
+                new StartsWith("Hello, "),
+                new EndsWith("друг!")
             )
         ).affirm();
     }
 
     @Test
-    public void readsStringBuilder() throws Exception {
+    void readsStringBuilder() throws Exception {
         final String starts = "Name it, ";
         final String ends = "then it exists!";
         new Assertion<>(
@@ -214,16 +193,14 @@ public final class InputOfTest {
                 )
             ),
             new AllOf<>(
-                new IterableOf<>(
-                    new StartsWith(starts),
-                    new EndsWith(ends)
-                )
+                new StartsWith(starts),
+                new EndsWith(ends)
             )
         ).affirm();
     }
 
     @Test
-    public void readsStringBuffer() throws Exception {
+    void readsStringBuffer() throws Exception {
         final String starts = "The future ";
         final String ends = "is now!";
         new Assertion<>(
@@ -237,16 +214,14 @@ public final class InputOfTest {
                 )
             ),
             new AllOf<>(
-                new IterableOf<>(
-                    new StartsWith(starts),
-                    new EndsWith(ends)
-                )
+                new StartsWith(starts),
+                new EndsWith(ends)
             )
         ).affirm();
     }
 
     @Test
-    public void readsArrayOfChars() throws Exception {
+    void readsArrayOfChars() throws Exception {
         new Assertion<>(
             "must read array of chars.",
             new TextOf(
@@ -258,16 +233,14 @@ public final class InputOfTest {
                 )
             ),
             new AllOf<>(
-                new IterableOf<>(
-                    new StartsWith("Hold "),
-                    new EndsWith("infinity")
-                )
+                new StartsWith("Hold "),
+                new EndsWith("infinity")
             )
         ).affirm();
     }
 
     @Test
-    public void readsEncodedArrayOfChars() throws Exception {
+    void readsEncodedArrayOfChars() throws Exception {
         new Assertion<>(
             "must read array of encoded chars.",
             new TextOf(
@@ -283,16 +256,14 @@ public final class InputOfTest {
                 StandardCharsets.UTF_8
             ),
             new AllOf<>(
-                new IterableOf<>(
-                    new StartsWith("O que sera"),
-                    new EndsWith(" que sera")
-                )
+                new StartsWith("O que sera"),
+                new EndsWith(" que sera")
             )
         ).affirm();
     }
 
     @Test
-    public void readsStringFromReader() throws Exception {
+    void readsStringFromReader() throws Exception {
         final String source = "hello, source!";
         new Assertion<>(
             "must read string through a reader",
@@ -300,13 +271,13 @@ public final class InputOfTest {
                 new InputOf(
                     new StringReader(source)
                 )
-            ).asString(),
-            new IsEqual<>(source)
+            ),
+            new IsText(source)
         ).affirm();
     }
 
     @Test
-    public void readsEncodedStringFromReader() throws Exception {
+    void readsEncodedStringFromReader() throws Exception {
         final String source = "hello, друг!";
         new Assertion<>(
             "must read encoded string through a reader",
@@ -317,14 +288,14 @@ public final class InputOfTest {
                         StandardCharsets.UTF_8
                     )
                 )
-            ).asString(),
-            new IsEqual<>(source)
+            ),
+            new IsText(source)
         ).affirm();
     }
 
     @Test
-    public void readsAnArrayOfBytes() throws Exception {
-        final byte[] bytes = new byte[] {(byte) 0xCA, (byte) 0xFE};
+    void readsAnArrayOfBytes() throws Exception {
+        final byte[] bytes = new byte[]{(byte) 0xCA, (byte) 0xFE};
         new Assertion<>(
             "must read array of bytes",
             new BytesOf(
@@ -335,53 +306,12 @@ public final class InputOfTest {
     }
 
     @Test
-    public void makesDataAvailable() throws Exception {
+    void makesDataAvailable() throws Exception {
         final String content = "Hello,חבר!";
         new Assertion<>(
             "must show that data is available",
-            new InputOf(content).stream().available(),
-            new MatcherOf<>(avl -> avl > 0)
-        ).affirm();
-    }
-
-    @Test
-    // @checkstyle MethodBodyCommentsCheck (50 lines)
-    public void readsSecureUrlContent() throws Exception {
-        final TrustManager[] managers = {
-            new X509TrustManager() {
-                @Override
-                public X509Certificate[] getAcceptedIssuers() {
-                    return new X509Certificate[0];
-                }
-
-                @Override
-                public void checkClientTrusted(
-                    final X509Certificate[] cert, final String arg) {
-                    // nothing to do
-                }
-
-                @Override
-                public void checkServerTrusted(
-                    final X509Certificate[] cert, final String arg) {
-                    // nothing to do
-                }
-            },
-        };
-        final SSLContext context = SSLContext.getInstance("TLS");
-        context.init(null, managers, new SecureRandom());
-        HttpsURLConnection.setDefaultSSLSocketFactory(
-            context.getSocketFactory()
-        );
-        new Assertion<>(
-            "Can't read bytes from HTTPS URL",
-            new BytesOf(
-                new InputOf(
-                    new URL(
-                        "https://www.yegor256.com/robots.txt"
-                    )
-                )
-            ).asBytes().length,
-            new MatcherOf<>(len -> len > 0)
+            new InputOf(content).stream(),
+            new Satisfies<>(s -> s.available() > 0)
         ).affirm();
     }
 
