@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -30,7 +30,9 @@ import java.util.logging.Level;
 import java.util.logging.Logger;
 import org.cactoos.bytes.BytesOf;
 import org.cactoos.scalar.LengthOf;
-import org.hamcrest.Matchers;
+import org.hamcrest.core.AllOf;
+import org.hamcrest.core.IsNot;
+import org.hamcrest.core.StringContains;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
@@ -41,7 +43,6 @@ import org.llorllale.cactoos.matchers.Assertion;
  *
  * @since 0.29
  * @checkstyle JavadocMethodCheck (500 lines)
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  */
 @SuppressWarnings(
     {
@@ -57,22 +58,22 @@ public final class LoggingOutputTest {
     public final TemporaryFolder folder = new TemporaryFolder();
 
     @Test
-    public void logWriteZero() {
+    public void logWriteZero() throws Exception {
         final Logger logger = new FakeLogger();
         new LengthOf(
             new TeeInput(
                 new InputOf(""),
                 new LoggingOutput(
-                    () -> new ByteArrayOutputStream(),
+                    ByteArrayOutputStream::new,
                     "memory",
                     logger
                 )
             )
-        ).intValue();
+        ).value();
         new Assertion<>(
-            "Can't log zero byte written to memory",
+            "Must log write zero byte written to memory",
             logger.toString(),
-            Matchers.containsString("Written 0 byte(s) to memory in ")
+            new StringContains("Written 0 byte(s) to memory in ")
         ).affirm();
     }
 
@@ -89,9 +90,9 @@ public final class LoggingOutputTest {
             out.write(new BytesOf("a").asBytes());
         }
         new Assertion<>(
-            "Can't log one byte written to memory",
+            "Must log one byte written to memory",
             logger.toString(),
-            Matchers.containsString("Written 1 byte(s) to memory in")
+            new StringContains("Written 1 byte(s) to memory in")
         ).affirm();
     }
 
@@ -108,13 +109,14 @@ public final class LoggingOutputTest {
             out.write(new BytesOf("Hello, товарищ!").asBytes());
         }
         new Assertion<>(
-            "Can't log 22 bytes written to memory",
+            "Must log 22 bytes written to memory",
             logger.toString(),
-            Matchers.containsString("Written 22 byte(s) to memory in")
+            new StringContains("Written 22 byte(s) to memory in")
         ).affirm();
     }
 
     @Test
+    @SuppressWarnings("unchecked")
     public void logWriteToLargeTextFile() throws Exception {
         final Logger logger = new FakeLogger();
         final Path temp = this.folder.newFolder("ccts-1").toPath();
@@ -130,24 +132,25 @@ public final class LoggingOutputTest {
                     new ResourceOf("org/cactoos/large-text.txt"),
                     new OutputTo(output)
                 )
-            ).intValue();
+            ).value();
         }
         new Assertion<>(
-            "Can't log write and close operations to text file",
+            "Must log write and close operations to text file",
             logger.toString(),
-            Matchers.allOf(
-                Matchers.not(
-                    Matchers.containsString(
+            new AllOf<>(
+                new IsNot<>(
+                    new StringContains(
                         "Written 16384 byte(s) to text file"
                     )
                 ),
-                Matchers.containsString("Written 74536 byte(s) to text file"),
-                Matchers.containsString("Closed output stream from text file")
+                new StringContains("Written 74536 byte(s) to text file"),
+                new StringContains("Closed output stream from text file")
             )
         ).affirm();
     }
 
     @Test
+    @SuppressWarnings("unchecked")
     public void logAllWriteToLargeTextFile() throws Exception {
         final Logger logger = new FakeLogger(Level.WARNING);
         final Path temp = this.folder.newFolder("ccts-2").toPath();
@@ -163,18 +166,18 @@ public final class LoggingOutputTest {
                     new ResourceOf("org/cactoos/large-text.txt"),
                     new OutputTo(output)
                 )
-            ).intValue();
+            ).value();
         }
         new Assertion<>(
-            "Can't log all write and close operations to text file",
+            "Must log all write and close operations to text file",
             logger.toString(),
-            Matchers.allOf(
-                Matchers.containsString("Written 16384 byte(s) to text file"),
-                Matchers.containsString("Written 32768 byte(s) to text file"),
-                Matchers.containsString("Written 49152 byte(s) to text file"),
-                Matchers.containsString("Written 65536 byte(s) to text file"),
-                Matchers.containsString("Written 74536 byte(s) to text file"),
-                Matchers.containsString("Closed output stream from text file")
+            new AllOf<>(
+                new StringContains("Written 16384 byte(s) to text file"),
+                new StringContains("Written 32768 byte(s) to text file"),
+                new StringContains("Written 49152 byte(s) to text file"),
+                new StringContains("Written 65536 byte(s) to text file"),
+                new StringContains("Written 74536 byte(s) to text file"),
+                new StringContains("Closed output stream from text file")
             )
         ).affirm();
     }
