@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -32,13 +32,12 @@ import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
 import org.llorllale.cactoos.matchers.Assertion;
-import org.llorllale.cactoos.matchers.TextIs;
+import org.llorllale.cactoos.matchers.IsText;
 
 /**
  * Test case for {@link ReaderOf}.
  * @since 0.13
  * @checkstyle JavadocMethodCheck (500 lines)
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  */
 @SuppressWarnings("PMD.TooManyMethods")
 public final class ReaderOfTest {
@@ -55,7 +54,7 @@ public final class ReaderOfTest {
         new Assertion<>(
             "Must read empty string",
             new TextOf(new ReaderOf(empty)),
-            new TextIs(empty)
+            new IsText(empty)
         ).affirm();
     }
 
@@ -64,7 +63,7 @@ public final class ReaderOfTest {
         new Assertion<>(
             "Must read chars var args",
             new TextOf(new ReaderOf('a', 'b', 'c')),
-            new TextIs("abc")
+            new IsText("abc")
         ).affirm();
     }
 
@@ -80,7 +79,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8
                 )
             ),
-            new TextIs(message)
+            new IsText(message)
         ).affirm();
     }
 
@@ -96,7 +95,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8.name()
                 )
             ),
-            new TextIs(message)
+            new IsText(message)
         ).affirm();
     }
 
@@ -111,7 +110,7 @@ public final class ReaderOfTest {
                     message.getBytes(StandardCharsets.UTF_8)
                 )
             ),
-            new TextIs(message)
+            new IsText(message)
         ).affirm();
     }
 
@@ -127,7 +126,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8
                 )
             ),
-            new TextIs(message)
+            new IsText(message)
         ).affirm();
     }
 
@@ -143,7 +142,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8.name()
                 )
             ),
-            new TextIs(message)
+            new IsText(message)
         ).affirm();
     }
 
@@ -159,7 +158,7 @@ public final class ReaderOfTest {
         new Assertion<>(
             "Must read from path",
             new TextOf(new ReaderOf(input)),
-            new TextIs(message)
+            new IsText(message)
         ).affirm();
     }
 
@@ -175,7 +174,7 @@ public final class ReaderOfTest {
         new Assertion<>(
             "Must read from file",
             new TextOf(new ReaderOf(input)),
-            new TextIs(message)
+            new IsText(message)
         ).affirm();
     }
 
@@ -197,7 +196,7 @@ public final class ReaderOfTest {
                         .toURL()
                 )
             ),
-            new TextIs(message)
+            new IsText(message)
         ).affirm();
     }
 
@@ -213,7 +212,7 @@ public final class ReaderOfTest {
         new Assertion<>(
             "Must read from uri",
             new TextOf(new ReaderOf(input.toURI())),
-            new TextIs(message)
+            new IsText(message)
         ).affirm();
     }
 
@@ -224,7 +223,7 @@ public final class ReaderOfTest {
         new Assertion<>(
             "Must read from bytes",
             new TextOf(new ReaderOf(new BytesOf(input))),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -235,7 +234,7 @@ public final class ReaderOfTest {
         new Assertion<>(
             "Must read from text",
             new TextOf(new ReaderOf(new TextOf(input))),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -251,7 +250,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8
                 )
             ),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -267,7 +266,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8.name()
                 )
             ),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -278,7 +277,7 @@ public final class ReaderOfTest {
         new Assertion<>(
             "Must read from char sequence",
             new TextOf(new ReaderOf(input)),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -294,7 +293,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8
                 )
             ),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -310,7 +309,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8.name()
                 )
             ),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -321,7 +320,7 @@ public final class ReaderOfTest {
         new Assertion<>(
             "Must read from input",
             new TextOf(new ReaderOf(new InputOf(input))),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -337,7 +336,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8
                 )
             ),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -353,7 +352,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8.name()
                 )
             ),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -369,7 +368,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8.newDecoder()
                 )
             ),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -380,7 +379,7 @@ public final class ReaderOfTest {
         new Assertion<>(
             "Must read from stream",
             new TextOf(new ReaderOf(new InputStreamOf(input))),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -396,7 +395,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8
                 )
             ),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -412,7 +411,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8.name()
                 )
             ),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 
@@ -428,7 +427,7 @@ public final class ReaderOfTest {
                     StandardCharsets.UTF_8.newDecoder()
                 )
             ),
-            new TextIs(input)
+            new IsText(input)
         ).affirm();
     }
 }
