@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -24,21 +24,19 @@
 package org.cactoos.io;
 
 import java.io.File;
-import java.io.IOException;
 import org.cactoos.bytes.BytesOf;
 import org.cactoos.scalar.LengthOf;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
 import org.llorllale.cactoos.matchers.Assertion;
-import org.llorllale.cactoos.matchers.InputHasContent;
+import org.llorllale.cactoos.matchers.HasContent;
 
 /**
  * Test case for {@link TeeInput}. Cases for ctors which use
  * {@link org.cactoos.Bytes} as an input.
  * @since 1.0
  * @checkstyle JavadocMethodCheck (100 lines)
- * @checkstyle ClassDataAbstractionCouplingCheck (100 lines)
  */
 public final class TeeInputFromBytesTest {
 
@@ -49,47 +47,47 @@ public final class TeeInputFromBytesTest {
     public final TemporaryFolder folder = new TemporaryFolder();
 
     @Test
-    public void copiesFromBytesToPath() throws IOException {
+    public void copiesFromBytesToPath() throws Exception {
         final String message =
             "Hello, товарищ path äÄ üÜ öÖ and ß";
         final File output = this.folder.newFile();
         new LengthOf(
             new TeeInput(new BytesOf(message), output.toPath())
-        ).intValue();
+        ).value();
         new Assertion<>(
             "Must copy bytes to file path",
             new InputOf(output),
-            new InputHasContent(message)
+            new HasContent(message)
         ).affirm();
     }
 
     @Test
-    public void copiesFromBytesToFile() throws IOException {
+    public void copiesFromBytesToFile() throws Exception {
         final String message =
             "Hello, товарищ file äÄ üÜ öÖ and ß";
         final File output = this.folder.newFile();
         new LengthOf(
             new TeeInput(new BytesOf(message), output)
-        ).intValue();
+        ).value();
         new Assertion<>(
             "Must copy bytes to file",
             new InputOf(output),
-            new InputHasContent(message)
+            new HasContent(message)
         ).affirm();
     }
 
     @Test
-    public void copiesFromBytesToOutput() throws IOException {
+    public void copiesFromBytesToOutput() throws Exception {
         final String message =
             "Hello, товарищ output äÄ üÜ öÖ and ß";
         final File output = this.folder.newFile();
         new LengthOf(
             new TeeInput(new BytesOf(message), new OutputTo(output))
-        ).intValue();
+        ).value();
         new Assertion<>(
             "Must bytes to output",
             new InputOf(output),
-            new InputHasContent(message)
+            new HasContent(message)
         ).affirm();
     }
 }
