@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -23,19 +23,22 @@
  */
 package org.cactoos.iterable;
 
+import java.util.Objects;
 import org.cactoos.list.ListOf;
+import org.cactoos.proc.ForEach;
 import org.cactoos.scalar.LengthOf;
-import org.hamcrest.Matchers;
+import org.hamcrest.collection.IsIterableWithSize;
+import org.hamcrest.core.IsEqual;
 import org.junit.Assert;
 import org.junit.Test;
 import org.llorllale.cactoos.matchers.Assertion;
+import org.llorllale.cactoos.matchers.HasValues;
 import org.llorllale.cactoos.matchers.Throws;
 
 /**
  * Test case for {@link Matched}.
  *
  * @since 0.39
- * @checkstyle MagicNumberCheck (500 lines)
  * @checkstyle JavadocMethodCheck (500 lines)
  */
 @SuppressWarnings("PMD.AvoidDuplicateLiterals")
@@ -49,7 +52,7 @@ public final class MatchedTest {
                 new IterableOf<>(1, 2, 3),
                 new IterableOf<>(1, 2, 3)
             ),
-            Matchers.hasItems(1, 2, 3)
+            new HasValues<>(1, 2, 3)
         ).affirm();
     }
 
@@ -92,7 +95,9 @@ public final class MatchedTest {
                 new IterableOf<>("1st elem", "2nd elem", "3rd elem"),
                 new IterableOf<>("`A` elem", "`B` elem", "'C' elem")
             ),
-            Matchers.iterableWithSize(3)
+            new IsIterableWithSize<>(
+                new IsEqual<>(3)
+            )
         ).affirm();
     }
 
@@ -105,31 +110,33 @@ public final class MatchedTest {
                 new IterableOf<>(1d, 2d, 3d),
                 new IterableOf<>(1L, 2L, 3L)
             ),
-            Matchers.iterableWithSize(3)
+            new IsIterableWithSize<>(
+                new IsEqual<>(3)
+            )
         ).affirm();
     }
 
     @Test(expected = IllegalStateException.class)
-    public void noCorrelation() {
+    public void noCorrelation() throws Exception {
         new LengthOf(
             new Matched<>(
                 (fst, snd) -> fst.endsWith("elem") && snd.endsWith("elem"),
                 new IterableOf<>("1st elem", "2nd"),
                 new IterableOf<>("`A` elem", "`B` elem")
             )
-        ).intValue();
+        ).value();
         Assert.fail("There is no 'endsWith'correlation between 2nd elements");
     }
 
     @Test(expected = IllegalStateException.class)
-    public void nonNullCorrelation() {
+    public void nonNullCorrelation() throws Exception {
         new LengthOf(
             new Matched<>(
                 (fst, snd) -> fst != null && snd != null,
                 new IterableOf<>("1st elem", "2nd elem", "3rd elem"),
                 new IterableOf<>("`A` elem", null, "'C' elem")
             )
-        ).intValue();
+        ).value();
         Assert.fail("There is no 'non-null' correlation between 2nd elements");
     }
 
@@ -142,7 +149,30 @@ public final class MatchedTest {
                 new IterableOf<>(1, 2, 3),
                 new IterableOf<>("1", "2", "3")
             ),
-            Matchers.iterableWithSize(3)
+            new IsIterableWithSize<>(
+                new IsEqual<>(3)
+            )
+        ).affirm();
+    }
+
+    @Test
+    public void shouldNotChangeAfterTraversing() throws Exception {
+        final Iterable<Integer> matched = new Matched<>(
+            Objects::equals,
+            new IterableOf<>(1, 2, 3),
+            new IterableOf<>(1, 2, 3)
+        );
+        final Iterable<Integer> copy = new ListOf<>(matched);
+        new ForEach<>(
+            (Integer ignored) -> {
+            }
+        ).exec(matched);
+        new Assertion<>(
+            "Elements must not be removed",
+            matched,
+            new IsEqual<>(
+                copy
+            )
         ).affirm();
     }
 
