@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -55,11 +55,11 @@ final class PagedTest {
         new Assertion<Iterable<String>>(
             "must have all page values",
             new Paged<>(
-                () -> pages.next().iterator(),
+                pages.next(),
                 page -> new Ternary<>(
-                    () -> pages.hasNext(),
-                    () -> pages.next().iterator(),
-                    () -> new IteratorOf<String>()
+                    pages::hasNext,
+                    pages::next,
+                    (Scalar<Iterable<String>>) IterableOf::new
                 ).value()
             ),
             new IsEqual<>(new Joined<>(first, second, third))
@@ -68,7 +68,7 @@ final class PagedTest {
 
     @Test
     @SuppressWarnings("unchecked")
-    void reportTotalPagedLength() {
+    void reportTotalPagedLength() throws AssertionError, Exception {
         final Iterable<String> first = new IterableOf<>("A", "six");
         final Iterable<String> second = new IterableOf<>("word", "long");
         final Iterable<String> third = new IterableOf<>("sentence");
@@ -79,18 +79,18 @@ final class PagedTest {
         new Assertion<Iterable<String>>(
             "length must be equal to total number of elements",
             new Paged<>(
-                () -> pages.next().iterator(),
+                pages.next(),
                 page -> new Ternary<>(
-                    () -> pages.hasNext(),
-                    () -> pages.next().iterator(),
-                    () -> new IteratorOf<String>()
+                    pages::hasNext,
+                    pages::next,
+                    (Scalar<Iterable<String>>) IterableOf::new
                 ).value()
             ),
             new IsIterableWithSize<>(
                 new IsEqual<>(
                     new LengthOf(
                         new Joined<>(first, second, third)
-                    ).intValue()
+                    ).value().intValue()
                 )
             )
         ).affirm();
@@ -103,13 +103,13 @@ final class PagedTest {
         final Iterator<Iterable<String>> pages = service.iterator();
         new Assertion<Scalar<String>>(
             "must throw an exception when first iterator is empty",
-            new ScalarOf<String>(
+            new ScalarOf<>(
                 () -> new Paged<>(
-                    () -> pages.next().iterator(),
+                    pages.next(),
                     page -> new Ternary<>(
-                        () -> pages.hasNext(),
-                        () -> pages.next().iterator(),
-                        () -> new IteratorOf<String>()
+                        pages::hasNext,
+                        pages::next,
+                        (Scalar<Iterable<String>>) IterableOf::new
                     ).value()
                 ).iterator().next()
             ),
