@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -32,18 +32,15 @@ import org.hamcrest.core.IsNot;
 import org.junit.jupiter.api.Test;
 import org.llorllale.cactoos.matchers.Assertion;
 import org.llorllale.cactoos.matchers.HasValues;
-import org.llorllale.cactoos.matchers.MatcherOf;
 import org.llorllale.cactoos.matchers.Throws;
 
 /**
  * Test case for {@link Immutable}.
  *
  * @since 1.16
- * @checkstyle MagicNumberCheck (500 lines)
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  */
 @SuppressWarnings({"PMD.TooManyMethods", "PMD.AvoidDuplicateLiterals"})
-public class ImmutableTest {
+class ImmutableTest {
 
     @Test
     void innerListIsDecorated() {
@@ -232,9 +229,7 @@ public class ImmutableTest {
                 new ListOf<>(1, 2)
             ).add(3),
             new Throws<>(
-                new MatcherOf<>(
-                    (String msg) -> msg.equals("#add(T): the list is read-only")
-                ),
+                "#add(T): the list is read-only",
                 UnsupportedOperationException.class
             )
         ).affirm();
@@ -248,9 +243,7 @@ public class ImmutableTest {
                 new ListOf<>("1", "2")
             ).remove("1"),
             new Throws<>(
-                new MatcherOf<>(
-                    (String msg) -> msg.equals("#remove(Object): the list is read-only")
-                ),
+                "#remove(Object): the list is read-only",
                 UnsupportedOperationException.class
             )
         ).affirm();
@@ -279,9 +272,7 @@ public class ImmutableTest {
                 new ListOf<>(1, 2)
             ).addAll(new ListOf<>(3, 4)),
             new Throws<>(
-                new MatcherOf<>(
-                    (String msg) -> msg.equals("#addAll(Collection): the list is read-only")
-                ),
+                "#addAll(Collection): the list is read-only",
                 UnsupportedOperationException.class
             )
         ).affirm();
@@ -295,9 +286,7 @@ public class ImmutableTest {
                 new ListOf<>(1, 2)
             ).addAll(2, new ListOf<>(3, 4)),
             new Throws<>(
-                new MatcherOf<>(
-                    (String msg) -> msg.equals("#addAll(int, Collection): the list is read-only")
-                ),
+                "#addAll(int, Collection): the list is read-only",
                 UnsupportedOperationException.class
             )
         ).affirm();
@@ -311,9 +300,7 @@ public class ImmutableTest {
                 new ListOf<>(1, 2, 3)
             ).removeAll(new ListOf<>(1, 3)),
             new Throws<>(
-                new MatcherOf<>(
-                    (String msg) -> msg.equals("#removeAll(): the list is read-only")
-                ),
+                "#removeAll(): the list is read-only",
                 UnsupportedOperationException.class
             )
         ).affirm();
@@ -327,9 +314,7 @@ public class ImmutableTest {
                 new ListOf<>(1, 2, 3)
             ).retainAll(new ListOf<>(1, 3)),
             new Throws<>(
-                new MatcherOf<>(
-                    (String msg) -> msg.equals("#retainAll(): the list is read-only")
-                ),
+                "#retainAll(): the list is read-only",
                 UnsupportedOperationException.class
             )
         ).affirm();
@@ -346,9 +331,7 @@ public class ImmutableTest {
                 return new Object();
             },
             new Throws<>(
-                new MatcherOf<>(
-                    (String msg) -> msg.equals("#clear(): the list is read-only")
-                ),
+                "#clear(): the list is read-only",
                 UnsupportedOperationException.class
             )
         ).affirm();
@@ -375,9 +358,7 @@ public class ImmutableTest {
                 new ListOf<>("a", "b")
             ).set(3, "c"),
             new Throws<>(
-                new MatcherOf<>(
-                    (String msg) -> msg.equals("#set(): the list is read-only")
-                ),
+                "#set(): the list is read-only",
                 UnsupportedOperationException.class
             )
         ).affirm();
@@ -394,9 +375,7 @@ public class ImmutableTest {
                 return new Object();
             },
             new Throws<>(
-                new MatcherOf<>(
-                    (String msg) -> msg.equals("#add(int, T): the list is read-only")
-                ),
+                "#add(int, T): the list is read-only",
                 UnsupportedOperationException.class
             )
         ).affirm();
@@ -410,9 +389,7 @@ public class ImmutableTest {
                 new ListOf<>("a", "b")
             ).remove(2),
             new Throws<>(
-                new MatcherOf<>(
-                    (String msg) -> msg.equals("#remove(int): the list is read-only")
-                ),
+                "#remove(int): the list is read-only",
                 UnsupportedOperationException.class
             )
         ).affirm();
@@ -487,9 +464,7 @@ public class ImmutableTest {
                 new ListOf<>("a", "b", "c")
             ).subList(0, 2).add("d"),
             new Throws<>(
-                new MatcherOf<>(
-                    (String msg) -> msg.equals("#add(T): the list is read-only")
-                ),
+                "#add(T): the list is read-only",
                 UnsupportedOperationException.class
             )
         ).affirm();
@@ -567,7 +542,7 @@ public class ImmutableTest {
             "subList's iterator must be immutable",
             () -> {
                 final ListIterator<String> iterator = new Immutable<>(
-                    new ListOf<String>("one", "two", "three")
+                    new ListOf<>("one", "two", "three")
                 )
                     .subList(0, 2)
                     .listIterator(0);
@@ -576,11 +551,7 @@ public class ImmutableTest {
                 return new Object();
             },
             new Throws<>(
-                new MatcherOf<>(
-                    (String msg) -> msg.equals(
-                        "List Iterator is read-only and doesn't allow rewriting items"
-                    )
-                ),
+                "List Iterator is read-only and doesn't allow rewriting items",
                 UnsupportedOperationException.class
             )
         ).affirm();
