@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -29,7 +29,7 @@ import java.util.ListIterator;
 import java.util.NoSuchElementException;
 import org.junit.jupiter.api.Test;
 import org.llorllale.cactoos.matchers.Assertion;
-import org.llorllale.cactoos.matchers.ScalarHasValue;
+import org.llorllale.cactoos.matchers.HasValue;
 import org.llorllale.cactoos.matchers.Throws;
 
 /**
@@ -37,7 +37,6 @@ import org.llorllale.cactoos.matchers.Throws;
  *
  * @since 0.35
  * @checkstyle JavadocMethodCheck (500 lines)
- * @checkstyle MagicNumberCheck (500 lines)
  */
 final class ListIteratorNoNullsTest {
 
@@ -92,7 +91,7 @@ final class ListIteratorNoNullsTest {
                 iterator.add(4);
                 return iterator.previous();
             },
-            new ScalarHasValue<>(4)
+            new HasValue<>(4)
         ).affirm();
     }
 
@@ -132,7 +131,7 @@ final class ListIteratorNoNullsTest {
                 iterator.set(4);
                 return iterator.previous();
             },
-            new ScalarHasValue<>(4)
+            new HasValue<>(4)
         ).affirm();
     }
 
