@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -36,9 +36,7 @@ import org.llorllale.cactoos.matchers.HasSize;
  * Test case for {@link ListOf}.
  *
  * @since 0.1
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  * @checkstyle JavadocMethodCheck (500 lines)
- * @checkstyle MagicNumberCheck (500 lines)
  */
 @SuppressWarnings(
     {
@@ -91,20 +89,18 @@ public final class ListOfTest {
 
     @Test(expected = IndexOutOfBoundsException.class)
     public void lowBoundTest() throws Exception {
-        // @checkstyle MagicNumber (1 line)
         new ListOf<>(Collections.nCopies(10, 0)).get(-1);
     }
 
     @Test(expected = IndexOutOfBoundsException.class)
     public void highBoundTest() throws Exception {
-        // @checkstyle MagicNumber (1 line)
         new ListOf<>(Collections.nCopies(10, 0)).get(11);
     }
 
     @Test
     public void makesListFromMappedIterable() throws Exception {
         final List<Integer> list = new ListOf<>(
-            new Mapped<Integer>(
+            new Mapped<>(
                 i -> i + 1,
                 new IterableOf<>(1, -1, 0, 1)
             )
