@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -29,7 +29,6 @@ import org.cactoos.Scalar;
 import org.cactoos.func.FuncOf;
 import org.cactoos.iterable.IterableOf;
 import org.cactoos.scalar.Constant;
-import org.hamcrest.MatcherAssert;
 import org.hamcrest.collection.IsMapContaining;
 import org.hamcrest.core.AllOf;
 import org.hamcrest.core.IsAnything;
@@ -37,20 +36,30 @@ import org.hamcrest.core.IsEqual;
 import org.hamcrest.core.StringStartsWith;
 import org.junit.jupiter.api.Test;
 import org.llorllale.cactoos.matchers.Assertion;
+import org.llorllale.cactoos.matchers.HasEntry;
 
 /**
  * Test case for {@link MapOf}.
  *
  * @since 0.4
  * @checkstyle JavadocMethodCheck (500 lines)
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  */
+@SuppressWarnings("PMD.TooManyMethods")
 final class MapOfTest {
 
+    @Test
+    void createsMapFromSingleKeyAndValue() {
+        new Assertion<>(
+            "Must create a map from single key and value",
+            new MapOf<>(-1, 1),
+            new HasEntry<>(-1, 1)
+        ).affirm();
+    }
+
     @Test
     void behavesAsMap() {
-        MatcherAssert.assertThat(
-            "Can't behave as a map",
+        new Assertion<>(
+            "Must behave as a map",
             new NoNulls<>(
                 new MapOf<Integer, Integer>(
                     new MapEntry<>(0, -1),
@@ -58,13 +67,42 @@ final class MapOfTest {
                 )
             ),
             new BehavesAsMap<>(1, 1)
+        ).affirm();
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    void createsMapFromIterable() {
+        new Assertion<>(
+            "Must behave as a map when created from iterable",
+            new MapOf<>(
+                new IterableOf<>(
+                    new MapEntry<>(0, -1),
+                    new MapEntry<>(1, 1)
+                )
+            ),
+            new BehavesAsMap<>(1, 1)
+        ).affirm();
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    void createsMapFromIterableVariable() {
+        final Iterable<Map.Entry<Integer, Integer>> list = new IterableOf<>(
+            new MapEntry<>(0, -1),
+            new MapEntry<>(1, 1)
         );
+        new Assertion<>(
+            "Must behave as a map when created from iterable",
+            new MapOf<Integer, Integer>((Iterable) list),
+            new BehavesAsMap<>(1, 1)
+        ).affirm();
     }
 
     @Test
     void convertsIterableToMap() {
-        MatcherAssert.assertThat(
-            "Can't convert iterable to map",
+        new Assertion<>(
+            "Must convert iterable to map",
             new MapOf<Integer, String>(
                 new MapEntry<>(0, "hello, "),
                 new MapEntry<>(1, "world!")
@@ -73,13 +111,13 @@ final class MapOfTest {
                 new IsEqual<>(0),
                 new StringStartsWith("hello")
             )
-        );
+        ).affirm();
     }
 
     @Test
     void createsMapWithFunctions() {
-        MatcherAssert.assertThat(
-            "Can't create a map with functions as values",
+        new Assertion<>(
+            "Must create a map with functions as values",
             new MapOf<Integer, Scalar<Boolean>>(
                 new MapEntry<>(0, () -> true),
                 new MapEntry<>(
@@ -90,84 +128,100 @@ final class MapOfTest {
                 )
             ),
             new IsMapContaining<>(new IsEqual<>(0), new IsAnything<>())
-        );
+        ).affirm();
     }
 
     @Test
     void integersToString() {
-        MatcherAssert.assertThat(
-            "Can't convert map of integers to string",
+        new Assertion<>(
+            "Must convert map of integers to string",
             new MapOf<Integer, Integer>(
                 new MapEntry<>(-1, 0),
                 new MapEntry<>(1, 2)
             ).toString(),
             new IsEqual<>("{-1=0, 1=2}")
-        );
+        ).affirm();
     }
 
     @Test
     void mapsToString() {
-        MatcherAssert.assertThat(
-            "Can't convert map op maps to string",
+        new Assertion<>(
+            "Must convert map op maps to string",
             new MapOf<Integer, Map<String, String>>(
                 new MapEntry<Integer, Map<String, String>>(
                     -1,
                     new MapOf<String, String>(
-                        new MapEntry<String, String>("first", "second"),
-                        new MapEntry<String, String>("4", "7")
+                        new MapEntry<>("first", "second"),
+                        new MapEntry<>("4", "7")
                     )
                 ),
                 new MapEntry<Integer, Map<String, String>>(
                     1,
                     new MapOf<String, String>(
-                        new MapEntry<String, String>("green", "red"),
-                        new MapEntry<String, String>("2.7", "3.1")
+                        new MapEntry<>("green", "red"),
+                        new MapEntry<>("2.7", "3.1")
                     )
                 )
             ).toString(),
             new IsEqual<>("{-1={4=7, first=second}, 1={green=red, 2.7=3.1}}")
-        );
+        ).affirm();
     }
 
     @Test
     void emptyToString() {
-        MatcherAssert.assertThat(
+        new Assertion<>(
             "Can't convert empty map to string",
             new MapOf<Integer, Map<String, String>>().toString(),
             new IsEqual<>("{}")
-        );
+        ).affirm();
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    void createsMapFromMapAndSingleKeyAndValue() {
+        new Assertion<>(
+            "Must create a map from map and single key and value",
+            new MapOf<>(
+                new MapOf<>(
+                    new MapEntry<>(0, 0)
+                ),
+                -1, 1
+            ),
+            new AllOf<>(
+                new HasEntry<>(0, 0),
+                new HasEntry<>(-1, 1)
+            )
+        ).affirm();
     }
 
     @Test
     @SuppressWarnings("unchecked")
     void createsMapFromMapAndMapEntries() {
-        MatcherAssert.assertThat(
-            "Can't create a map from map and map entries",
+        new Assertion<>(
+            "Must create a map from map and map entries",
             new MapOf<Integer, Integer>(
-                new MapOf<Integer, Integer>(
-                    new MapEntry<Integer, Integer>(0, 0)
+                new MapOf<>(
+                    new MapEntry<>(0, 0)
                 ),
-                new MapEntry<Integer, Integer>(1, 1)
+                new MapEntry<>(1, 1)
             ),
             new AllOf<>(
-                new IterableOf<>(
-                    new IsMapContaining<>(new IsEqual<>(0), new IsEqual<>(0)),
-                    new IsMapContaining<>(new IsEqual<>(1), new IsEqual<>(1))
-                )
+                new HasEntry<>(0, 0),
+                new HasEntry<>(1, 1)
             )
-        );
+        ).affirm();
     }
 
     @Test
     void createsMapFromFunctionsAndIterable() {
         new Assertion<>(
             "Must create a map from functions and iterable.",
-            new MapOf<Integer, Integer>(
-                new FuncOf<Integer, Integer>(new Constant<>(0)),
-                new FuncOf<Integer, Integer>(new Constant<>(0)),
-                new IterableOf<Integer>(0)
+            new MapOf<>(
+                new FuncOf<>(new Constant<>(0)),
+                new FuncOf<>(new Constant<>(0)),
+                new IterableOf<>(0)
             ),
-            new IsMapContaining<>(new IsEqual<>(0), new IsEqual<>(0))
+            new HasEntry<>(0, 0)
         ).affirm();
     }
 
@@ -175,20 +229,18 @@ final class MapOfTest {
     @SuppressWarnings("unchecked")
     void createsMapFromMapFunctionsAndIterable() {
         new Assertion<>(
-            "Can't create a map from map, functions and iterable.",
-            new MapOf<Integer, Integer>(
-                new FuncOf<Integer, Integer>(new Constant<>(0)),
-                new FuncOf<Integer, Integer>(new Constant<>(0)),
-                new MapOf<Integer, Integer>(
-                    new MapEntry<Integer, Integer>(1, 1)
+            "Must create a map from map, functions and iterable.",
+            new MapOf<>(
+                new FuncOf<>(new Constant<>(0)),
+                new FuncOf<>(new Constant<>(0)),
+                new MapOf<>(
+                    new MapEntry<>(1, 1)
                 ),
                 new IterableOf<>(0)
             ),
             new AllOf<>(
-                new IterableOf<>(
-                    new IsMapContaining<>(new IsEqual<>(0), new IsEqual<>(0)),
-                    new IsMapContaining<>(new IsEqual<>(1), new IsEqual<>(1))
-                )
+                new HasEntry<>(0, 0),
+                new HasEntry<>(1, 1)
             )
         ).affirm();
     }
