@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -27,7 +27,7 @@ import java.util.concurrent.atomic.AtomicReference;
 import org.cactoos.func.FuncOf;
 import org.junit.jupiter.api.Test;
 import org.llorllale.cactoos.matchers.Assertion;
-import org.llorllale.cactoos.matchers.MatcherOf;
+import org.llorllale.cactoos.matchers.Satisfies;
 
 /**
  * Test case for {@link ProcOf}.
@@ -48,7 +48,7 @@ final class ProcOfTest {
                     }
                 )
             ),
-            new MatcherOf<>(
+            new Satisfies<>(
                 proc -> {
                     final Object input = new Object();
                     proc.exec(input);
@@ -64,11 +64,9 @@ final class ProcOfTest {
         new Assertion<>(
             "Must execute Proc with Lambda",
             new ProcOf<>(
-                input -> {
-                    done.set(input);
-                }
+                done::set
             ),
-            new MatcherOf<>(
+            new Satisfies<>(
                 proc -> {
                     final Object input = new Object();
                     proc.exec(input);
