@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -33,22 +33,19 @@ import org.cactoos.iterable.Mapped;
 import org.cactoos.list.ListOf;
 import org.cactoos.list.Synced;
 import org.cactoos.proc.ProcNoNulls;
-import org.hamcrest.Matcher;
 import org.hamcrest.MatcherAssert;
 import org.hamcrest.Matchers;
 import org.hamcrest.collection.IsIterableContainingInAnyOrder;
+import org.hamcrest.core.IsEqual;
 import org.junit.jupiter.api.Test;
 import org.llorllale.cactoos.matchers.Assertion;
-import org.llorllale.cactoos.matchers.MatcherOf;
-import org.llorllale.cactoos.matchers.ScalarHasValue;
+import org.llorllale.cactoos.matchers.HasValue;
 
 /**
  * Test case for {@link AndInThreads}.
  * @since 0.25
- * @checkstyle JavadocMethodCheck (500 lines)
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  */
-@SuppressWarnings({"PMD.TooManyMethods", "PMD.AvoidDuplicateLiterals"})
+@SuppressWarnings({"PMD.TooManyMethods", "PMD.AvoidDuplicateLiterals", "unchecked"})
 final class AndInThreadsTest {
 
     @Test
@@ -60,7 +57,7 @@ final class AndInThreadsTest {
                 new True(),
                 new True()
             ),
-            new ScalarHasValue<>(true)
+            new HasValue<>(true)
         ).affirm();
     }
 
@@ -73,7 +70,7 @@ final class AndInThreadsTest {
                 new False(),
                 new True()
             ),
-            new ScalarHasValue<>(false)
+            new HasValue<>(false)
         ).affirm();
     }
 
@@ -88,7 +85,7 @@ final class AndInThreadsTest {
                     new False()
                 )
             ),
-            new ScalarHasValue<>(false)
+            new HasValue<>(false)
         ).affirm();
     }
 
@@ -96,8 +93,8 @@ final class AndInThreadsTest {
     void emptyIterable() throws Exception {
         new Assertion<>(
             "Must iterate over empty iterable",
-            new AndInThreads(new IterableOf<Scalar<Boolean>>()),
-            new ScalarHasValue<>(true)
+            new AndInThreads(new IterableOf<>()),
+            new HasValue<>(true)
         ).affirm();
     }
 
@@ -112,23 +109,15 @@ final class AndInThreadsTest {
                     new IterableOf<>("hello", "world")
                 )
             ),
-            new ScalarHasValue<>(true)
+            new HasValue<>(true)
         ).affirm();
         new Assertion<>(
             "Iterable must contain elements in any order",
             list,
-            new IsIterableContainingInAnyOrder<String>(
-                new ListOf<Matcher<? super String>>(
-                    new MatcherOf<>(
-                        text -> {
-                            return "hello".equals(text);
-                        }
-                    ),
-                    new MatcherOf<>(
-                        text -> {
-                            return "world".equals(text);
-                        }
-                    )
+            new IsIterableContainingInAnyOrder<>(
+                new ListOf<>(
+                    new IsEqual<>("hello"),
+                    new IsEqual<>("world")
                 )
             )
         ).affirm();
@@ -141,7 +130,7 @@ final class AndInThreadsTest {
                 input -> input > 0,
                 1, -1, 0
             ),
-            new ScalarHasValue<>(false)
+            new HasValue<>(false)
         );
     }
 
@@ -150,8 +139,8 @@ final class AndInThreadsTest {
         MatcherAssert.assertThat(
             new AndInThreads(
                 new ListOf<Scalar<Boolean>>(
-                    new Constant<Boolean>(true),
-                    new Constant<Boolean>(true)
+                    new Constant<>(true),
+                    new Constant<>(true)
                 )
             ).value(),
             Matchers.equalTo(true)
@@ -169,18 +158,10 @@ final class AndInThreadsTest {
         ).value();
         MatcherAssert.assertThat(
             list,
-            new IsIterableContainingInAnyOrder<Integer>(
-                new ListOf<Matcher<? super Integer>>(
-                    new MatcherOf<>(
-                        value -> {
-                            return value.equals(1);
-                        }
-                    ),
-                    new MatcherOf<>(
-                        value -> {
-                            return value.equals(2);
-                        }
-                    )
+            new IsIterableContainingInAnyOrder<>(
+                new ListOf<>(
+                    new IsEqual<>(1),
+                    new IsEqual<>(2)
                 )
             )
         );
@@ -197,18 +178,10 @@ final class AndInThreadsTest {
         ).value();
         MatcherAssert.assertThat(
             list,
-            new IsIterableContainingInAnyOrder<Integer>(
-                new ListOf<Matcher<? super Integer>>(
-                    new MatcherOf<>(
-                        value -> {
-                            return value.equals(1);
-                        }
-                    ),
-                    new MatcherOf<>(
-                        value -> {
-                            return value.equals(2);
-                        }
-                    )
+            new IsIterableContainingInAnyOrder<>(
+                new ListOf<>(
+                    new IsEqual<>(1),
+                    new IsEqual<>(2)
                 )
             )
         );
@@ -219,8 +192,8 @@ final class AndInThreadsTest {
         MatcherAssert.assertThat(
             new AndInThreads(
                 Executors.newSingleThreadExecutor(),
-                new Constant<Boolean>(false),
-                new Constant<Boolean>(false)
+                new Constant<>(false),
+                new Constant<>(false)
             ).value(),
             Matchers.equalTo(false)
         );
@@ -232,8 +205,8 @@ final class AndInThreadsTest {
             new AndInThreads(
                 Executors.newSingleThreadExecutor(),
                 new ListOf<Scalar<Boolean>>(
-                    new Constant<Boolean>(true),
-                    new Constant<Boolean>(false)
+                    new Constant<>(true),
+                    new Constant<>(false)
                 )
             ).value(),
             Matchers.equalTo(false)
@@ -244,7 +217,7 @@ final class AndInThreadsTest {
     void worksWithEmptyIterableScalarBoolean() throws Exception {
         MatcherAssert.assertThat(
             new AndInThreads(
-                new ListOf<Scalar<Boolean>>()
+                new ListOf<>()
             ).value(),
             Matchers.equalTo(true)
         );
