@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -23,22 +23,20 @@
  */
 package org.cactoos.scalar;
 
-import java.util.Properties;
 import org.cactoos.io.InputOf;
 import org.cactoos.map.MapEntry;
 import org.cactoos.map.MapOf;
 import org.junit.jupiter.api.Test;
 import org.llorllale.cactoos.matchers.Assertion;
-import org.llorllale.cactoos.matchers.MatcherOf;
-import org.llorllale.cactoos.matchers.ScalarHasValue;
+import org.llorllale.cactoos.matchers.HasProperty;
+import org.llorllale.cactoos.matchers.HasValue;
 
 /**
  * Test case for {@link PropertiesOf}.
  *
  * @since 0.7
- * @checkstyle JavadocMethodCheck (500 lines)
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  */
+@SuppressWarnings("PMD.AvoidDuplicateLiterals")
 final class PropertiesOfTest {
 
     @Test
@@ -48,14 +46,8 @@ final class PropertiesOfTest {
             new PropertiesOf(
                 "foo=Hello, world!\nbar=works fine?\n"
             ),
-            new ScalarHasValue<>(
-                new MatcherOf<Properties>(
-                    props -> {
-                        return "Hello, world!".equals(
-                            props.getProperty("foo")
-                        );
-                    }
-                )
+            new HasValue<>(
+                new HasProperty("foo", "Hello, world!")
             )
         ).affirm();
     }
@@ -67,14 +59,8 @@ final class PropertiesOfTest {
             new PropertiesOf(
                 new InputOf("greet=Hello, inner world!\nask=works fine?\n")
             ),
-            new ScalarHasValue<>(
-                new MatcherOf<Properties>(
-                    props -> {
-                        return "Hello, inner world!".equals(
-                            props.getProperty("greet")
-                        );
-                    }
-                )
+            new HasValue<>(
+                new HasProperty("greet", "Hello, inner world!")
             )
         ).affirm();
     }
@@ -89,12 +75,8 @@ final class PropertiesOfTest {
                     new MapEntry<>(1, "how are you?")
                 )
             ),
-            new ScalarHasValue<>(
-                new MatcherOf<Properties>(
-                    props -> {
-                        return props.getProperty("0").endsWith(", world");
-                    }
-                )
+            new HasValue<>(
+                new HasProperty("0", "hello, world")
             )
         ).affirm();
     }
@@ -107,12 +89,8 @@ final class PropertiesOfTest {
                 new MapEntry<>(0, "hello world"),
                 new MapEntry<>(1, "How are you?")
             ),
-            new ScalarHasValue<>(
-                new MatcherOf<Properties>(
-                    props -> {
-                        return props.getProperty("0").endsWith(" world");
-                    }
-                )
+            new HasValue<>(
+                new HasProperty("0", "hello world")
             )
         ).affirm();
     }
