@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -29,7 +29,7 @@ import org.cactoos.Scalar;
 import org.cactoos.iterable.IterableOf;
 import org.junit.Test;
 import org.llorllale.cactoos.matchers.Assertion;
-import org.llorllale.cactoos.matchers.ScalarHasValue;
+import org.llorllale.cactoos.matchers.HasValue;
 
 /**
  * Test case for {@link Reduced}.
@@ -55,7 +55,7 @@ public final class ReducedTest {
                 (first, last) -> first,
                 new IterableOf<Scalar<Integer>>(() -> single)
             ),
-            new ScalarHasValue<>(single)
+            new HasValue<>(single)
         ).affirm();
     }
 
@@ -74,7 +74,7 @@ public final class ReducedTest {
                     () -> three
                 )
             ),
-            new ScalarHasValue<>(one)
+            new HasValue<>(one)
         ).affirm();
     }
 
@@ -93,7 +93,7 @@ public final class ReducedTest {
                     () -> three
                 )
             ),
-            new ScalarHasValue<>(three)
+            new HasValue<>(three)
         ).affirm();
     }
 
@@ -104,13 +104,13 @@ public final class ReducedTest {
         final String three = "Three";
         new Assertion<>(
             "Must concatenate the strings in vararg array",
-            new Reduced<String>(
+            new Reduced<>(
                 (first, last) -> first + last,
                 one,
                 two,
                 three
             ),
-            new ScalarHasValue<>("OneTwoThree")
+            new HasValue<>("OneTwoThree")
         ).affirm();
     }
 }
