@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -30,14 +30,13 @@ import org.cactoos.Fallback;
 import org.cactoos.iterable.IterableOf;
 import org.junit.Test;
 import org.llorllale.cactoos.matchers.Assertion;
-import org.llorllale.cactoos.matchers.ScalarHasValue;
+import org.llorllale.cactoos.matchers.HasValue;
 
 /**
  * Test case for {@link ScalarWithFallback}.
  *
  * @since 0.31
  * @checkstyle JavadocMethodCheck (500 lines)
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  */
 @SuppressWarnings("unchecked")
 public final class ScalarWithFallbackTest {
@@ -56,7 +55,7 @@ public final class ScalarWithFallbackTest {
                     )
                 )
             ),
-            new ScalarHasValue<>(message)
+            new HasValue<>(message)
         ).affirm();
     }
 
@@ -65,14 +64,14 @@ public final class ScalarWithFallbackTest {
         final String message = "Main function's result #1 (exp & flbck)";
         new Assertion<>(
             "Using the main function if no exception (exp & flbck)",
-            new ScalarWithFallback<String>(
+            new ScalarWithFallback<>(
                 () -> message,
                 new Fallback.From<>(
                     IOException.class,
                     Throwable::getMessage
                 )
             ),
-            new ScalarHasValue<>(message)
+            new HasValue<>(message)
         ).affirm();
     }
 
@@ -81,14 +80,14 @@ public final class ScalarWithFallbackTest {
         final String message = "Main function's result #1 (exp iterable & flbck)";
         new Assertion<>(
             "Using the main function if no exception (exp iterable & flbck)",
-            new ScalarWithFallback<String>(
+            new ScalarWithFallback<>(
                 () -> message,
                 new Fallback.From<>(
                     new IterableOf<>(IOException.class),
                     Throwable::getMessage
                 )
             ),
-            new ScalarHasValue<>(message)
+            new HasValue<>(message)
         ).affirm();
     }
 
@@ -111,7 +110,7 @@ public final class ScalarWithFallbackTest {
                     )
                 )
             ),
-            new ScalarHasValue<>(message)
+            new HasValue<>(message)
         ).affirm();
     }
 
@@ -120,7 +119,7 @@ public final class ScalarWithFallbackTest {
         final String message = "Fallback from IOException (exp & flbck)";
         new Assertion<>(
             "Using a single fallback in case of exception (exp & flbck)",
-            new ScalarWithFallback<String>(
+            new ScalarWithFallback<>(
                 () -> {
                     throw new IOException("Failure with IOException (exp & flbck)");
                 },
@@ -129,7 +128,7 @@ public final class ScalarWithFallbackTest {
                     exp -> message
                 )
             ),
-            new ScalarHasValue<>(message)
+            new HasValue<>(message)
         ).affirm();
     }
 
@@ -138,7 +137,7 @@ public final class ScalarWithFallbackTest {
         final String message = "Fallback from IOException (exp iterable & flbck)";
         new Assertion<>(
             "Using a single fallback in case of exception (exp iterable & flbck)",
-            new ScalarWithFallback<String>(
+            new ScalarWithFallback<>(
                 () -> {
                     throw new IOException("Failure with IOException (exp iterable & flbck)");
                 },
@@ -147,7 +146,7 @@ public final class ScalarWithFallbackTest {
                     exp -> message
                 )
             ),
-            new ScalarHasValue<>(message)
+            new HasValue<>(message)
         ).affirm();
     }
 
@@ -169,7 +168,7 @@ public final class ScalarWithFallbackTest {
                     )
                 )
             ),
-            new ScalarHasValue<>(message)
+            new HasValue<>(message)
         ).affirm();
     }
 
@@ -193,7 +192,7 @@ public final class ScalarWithFallbackTest {
                     )
                 )
             ),
-            new ScalarHasValue<>(expected)
+            new HasValue<>(expected)
         ).affirm();
     }
 
