@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -34,14 +34,12 @@ import org.hamcrest.core.IsEqual;
 import org.hamcrest.core.IsNot;
 import org.junit.jupiter.api.Test;
 import org.llorllale.cactoos.matchers.Assertion;
-import org.llorllale.cactoos.matchers.TextIs;
+import org.llorllale.cactoos.matchers.IsText;
 
 /**
  * Test case for {@link Sorted}.
  * @since 1.0.0
- * @checkstyle MagicNumber (500 line)
  * @checkstyle JavadocMethodCheck (500 lines)
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  */
 @SuppressWarnings(
     {
@@ -107,10 +105,10 @@ final class SortedTest {
             ),
             new IsIterableContainingInOrder<Text>(
                 new ListOf<>(
-                    new TextIs("ab"),
-                    new TextIs("cd"),
-                    new TextIs("ef"),
-                    new TextIs("gh")
+                    new IsText("ab"),
+                    new IsText("cd"),
+                    new IsText("ef"),
+                    new IsText("gh")
                 )
             )
         ).affirm();
