@@ -1,7 +1,7 @@
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2017-2020 Yegor Bugayenko
+ * Copyright (c) 2017-2022 Yegor Bugayenko
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -25,18 +25,15 @@ package org.cactoos.text;
 
 import java.util.concurrent.atomic.AtomicInteger;
 import org.cactoos.Text;
-import org.cactoos.iterable.IterableOf;
 import org.hamcrest.core.AllOf;
 import org.junit.jupiter.api.Test;
 import org.llorllale.cactoos.matchers.Assertion;
-import org.llorllale.cactoos.matchers.TextIs;
+import org.llorllale.cactoos.matchers.IsText;
 
 /**
  * Test case for {@link Abbreviated}.
  * @since 0.29
  * @checkstyle JavadocMethodCheck (500 lines)
- * @checkstyle MagicNumberCheck (500 lines)
- * @checkstyle ClassDataAbstractionCouplingCheck (500 lines)
  */
 @SuppressWarnings("PMD.TooManyMethods")
 final class AbbreviatedTest {
@@ -47,7 +44,7 @@ final class AbbreviatedTest {
         new Assertion<>(
             "Must abbreviate an msg text",
             new Abbreviated(msg, 8),
-            new TextIs(msg)
+            new IsText(msg)
         ).affirm();
     }
 
@@ -56,7 +53,7 @@ final class AbbreviatedTest {
         new Assertion<>(
             "Must abbreviate a text",
             new Abbreviated("hello world", 8),
-            new TextIs("hello...")
+            new IsText("hello...")
         ).affirm();
     }
 
@@ -65,7 +62,7 @@ final class AbbreviatedTest {
         new Assertion<>(
             "Must abbreviate a text one char smaller",
             new Abbreviated("oo programming", 10),
-            new TextIs("oo prog...")
+            new IsText("oo prog...")
         ).affirm();
     }
 
@@ -75,7 +72,7 @@ final class AbbreviatedTest {
         new Assertion<>(
             "Must abbreviate a text with same length",
             new Abbreviated(msg, 15),
-            new TextIs(msg)
+            new IsText(msg)
         ).affirm();
     }
 
@@ -85,7 +82,7 @@ final class AbbreviatedTest {
         new Assertion<>(
             "Must abbreviate a text one char bigger",
             new Abbreviated(msg, 17),
-            new TextIs(msg)
+            new IsText(msg)
         ).affirm();
     }
 
@@ -95,7 +92,7 @@ final class AbbreviatedTest {
         new Assertion<>(
             "Must abbreviate a text two chars bigger",
             new Abbreviated(msg, 15),
-            new TextIs(msg)
+            new IsText(msg)
         ).affirm();
     }
 
@@ -105,7 +102,7 @@ final class AbbreviatedTest {
         new Assertion<>(
             "Must abbreviate a text with width bigger than length",
             new Abbreviated(msg, 50),
-            new TextIs(msg)
+            new IsText(msg)
         ).affirm();
     }
 
@@ -114,11 +111,9 @@ final class AbbreviatedTest {
         new Assertion<>(
             "Must abbreviate a text bigger than default max width",
             new Abbreviated(
-                // @checkstyle LineLengthCheck (1 line)
                 "The quick brown fox jumps over the lazy black dog and after that returned to the cave"
             ),
-            new TextIs(
-                // @checkstyle LineLengthCheck (1 line)
+            new IsText(
                 "The quick brown fox jumps over the lazy black dog and after that returned to ..."
             )
         ).affirm();
@@ -146,13 +141,11 @@ final class AbbreviatedTest {
                 15
             ),
             new AllOf<>(
-                new IterableOf<>(
-                    new TextIs(
-                        "The quick br..."
-                    ),
-                    new TextIs(
-                        "The lazy bla..."
-                    )
+                new IsText(
+                    "The quick br..."
+                ),
+                new IsText(
+                    "The lazy bla..."
                 )
             )
         ).affirm();
